import path from 'path';
import webpack from 'webpack';

// const BundleAnalyzerPlugin = require('webpack-bundle-analyzer').BundleAnalyzerPlugin;

import conf from './conf';

import WriteFilePlugin from 'write-file-webpack-plugin';

const config = {

    context: path.resolve(__dirname, '../'),

    entry: conf.isProduction ? {
        main: [
            `./wp-content/themes/${conf.name}/js/main`
        ]
    } : {
        main: [
            `./wp-content/themes/${conf.name}/js/main`,
            'webpack/hot/dev-server',
            'webpack-hot-middleware/client'
        ]
    },

    mode: conf.env,

    watchOptions: {
        poll: true
    },

    module: {
        rules: [{
            test: /\.js?$/,
            exclude: /node_modules/,
            use: {
                loader: 'babel-loader'
            }
        }]
    },

    output: {
        filename: `wp-content/themes/${conf.name}/js/[name]${conf.isProduction ? '-[contenthash:8]' : ''}.min.js`,
        chunkFilename: `wp-content/themes/${conf.name}/js/components/[name]${conf.isProduction ? '-[contenthash:8]' : ''}.min.js`,
        path: path.resolve(__dirname, '../'),
        publicPath: '/'
    },

    plugins: conf.isProduction ? [
        new webpack.DefinePlugin({
            'process.env.NODE_ENV': conf.env
        })
    ] : [
        new webpack.DefinePlugin({
            'process.env.NODE_ENV': conf.env
        }),
        new WriteFilePlugin({
            test: /wp-content\/.+\.js?$/
        }),
        new webpack.HotModuleReplacementPlugin()
    ]
};

function scripts () {
    return new Promise(resolve => webpack(config, (err, stats) => {
        if (err) {
            console.log('Webpack', err);
        }

        console.log(stats.toString({ /* stats options */ }));

        resolve();
    }));
}

module.exports = { config, scripts };
